@@ -1,7 +1,7 @@
 /*
  * lingot, a musical instrument tuner.
  *
- * Copyright (C) 2004-2010  Ibán Cereijo Graña, Jairo Chapela Martínez.
+ * Copyright (C) 2004-2011  Ibán Cereijo Graña, Jairo Chapela Martínez.
  *
  * This file is part of lingot.
  *
@@ -31,7 +31,7 @@
 
 #include "lingot-defs.h"
 #include "lingot-config.h"
-#include "lingot-mainframe.h"
+#include "lingot-gui-mainframe.h"
 #include "lingot-i18n.h"
 
 #include <gtk/gtk.h>
@@ -98,6 +98,7 @@ int main(int argc, char *argv[]) {
 
 		// new configuration with default values.
 		LingotConfig* new_conf = lingot_config_new();
+		lingot_config_restore_default_values(new_conf);
 		lingot_config_save(new_conf, CONFIG_FILE_NAME);
 		lingot_config_destroy(new_conf);
 
@@ -106,7 +107,7 @@ int main(int argc, char *argv[]) {
 	} else
 		fclose(fp);
 
-	lingot_mainframe_create(argc, argv);
+	lingot_gui_mainframe_create(argc, argv);
 
 	return 0;
 }
